# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.models.credit_card_invoice_full import CreditCardInvoiceFull

class TestCreditCardInvoiceFull(unittest.TestCase):
    """CreditCardInvoiceFull unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreditCardInvoiceFull:
        """Test CreditCardInvoiceFull
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreditCardInvoiceFull`
        """
        model = CreditCardInvoiceFull()
        if include_optional:
            return CreditCardInvoiceFull(
                id = 1,
                var_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                starting_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                closing_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                amount_cents = 0,
                payment_amount_cents = 0,
                balance_cents = 0,
                previous_balance_cents = 0,
                credit_card_id = 1,
                transactions = [
                    {"id":2477483422,"description":"Despesa fixa","date":"2015-09-16","paid":true,"amount_cents":0,"total_installments":1,"installment":1,"recurring":false,"account_id":6632818,"category_id":120321159,"notes":"Pagamento via boleto","attachments_count":0,"credit_card_id":null,"credit_card_invoice_id":null,"paid_credit_card_id":null,"paid_credit_card_invoice_id":null,"oposite_transaction_id":null,"oposite_account_id":null,"created_at":"2023-04-08T12:32:16-03:00","updated_at":"2023-04-08T12:32:16-03:00","tags":[],"attachments":[]}
                    ],
                payments = [
                    {"id":2477483422,"description":"Despesa fixa","date":"2015-09-16","paid":true,"amount_cents":0,"total_installments":1,"installment":1,"recurring":false,"account_id":6632818,"category_id":120321159,"notes":"Pagamento via boleto","attachments_count":0,"credit_card_id":null,"credit_card_invoice_id":null,"paid_credit_card_id":null,"paid_credit_card_invoice_id":null,"oposite_transaction_id":null,"oposite_account_id":null,"created_at":"2023-04-08T12:32:16-03:00","updated_at":"2023-04-08T12:32:16-03:00","tags":[],"attachments":[]}
                    ]
            )
        else:
            return CreditCardInvoiceFull(
        )
        """

    def testCreditCardInvoiceFull(self):
        """Test CreditCardInvoiceFull"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
