# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.models.credit_card_input import CreditCardInput

class TestCreditCardInput(unittest.TestCase):
    """CreditCardInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreditCardInput:
        """Test CreditCardInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreditCardInput`
        """
        model = CreditCardInput()
        if include_optional:
            return CreditCardInput(
                name = '',
                description = '',
                card_network = '',
                closing_day = 1,
                due_day = 1,
                limit_cents = 0,
                archived = True,
                default = True,
                institution_id = ''
            )
        else:
            return CreditCardInput(
                name = '',
                closing_day = 1,
                due_day = 1,
        )
        """

    def testCreditCardInput(self):
        """Test CreditCardInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
